@@ -1,8 +1,11 @@
+//! Composable asynchronous iteration.
+
 mod buffer;
 mod debounce;
 mod delay;
 mod interval;
 mod into_stream;
+mod sample;
 mod stream_ext;
 mod throttle;
 mod timeout;
@@ -12,6 +15,7 @@ pub use debounce::Debounce;
 pub use delay::Delay;
 pub use interval::{interval, Interval};
 pub use into_stream::IntoStream;
+pub use sample::Sample;
 pub use stream_ext::StreamExt;
 pub use throttle::Throttle;
 pub use timeout::Timeout;
