@@ -2,19 +2,19 @@ use std::future::Future;
 use std::pin::Pin;
 use std::task::{Context, Poll};
 
-use async_io::Timer;
+use async_io::Timer as AsyncTimer;
 use pin_project_lite::pin_project;
 
-use crate::future::ResetDeadlineFuture;
+use crate::future::Deadline;
 use crate::time::{Duration, Instant};
 
 /// Sleeps for the specified amount of time.
 ///
-/// This future can be `reset` to be moved
+/// This future can be `push_deadline` to be moved
 pub fn sleep(dur: Duration) -> Sleep {
     Sleep {
         dur,
-        timer: Timer::after(dur.into()),
+        timer: AsyncTimer::after(dur.into()),
         completed: false,
     }
 }
@@ -24,7 +24,7 @@ pin_project! {
     #[must_use = "futures do nothing unless polled or .awaited"]
     pub struct Sleep {
         #[pin]
-        timer: Timer,
+        timer: AsyncTimer,
         completed: bool,
         dur: Duration,
     }
@@ -46,9 +46,9 @@ impl Future for Sleep {
     }
 }
 
-impl ResetDeadlineFuture for Sleep {
+impl Deadline for Sleep {
     /// Resets the timer to be `Instant::now()` + `Duration` into the future.
-    fn reset_deadline(self: std::pin::Pin<&mut Self>) {
+    fn push_deadline(self: std::pin::Pin<&mut Self>) {
         let mut this = self.project();
         this.timer.set_after(**this.dur);
         *this.completed = false;
